#
# This rpm is based on the git tree from:
# git://git.kernel.org/pub/scm/linux/kernel/git/dwmw2/linux-firmware.git
# version is date of the younger commit
#

Summary:	Extra linux kernel firmware files
Name:   	kernel-firmware-extra
Version:	20110517
Release:	%mkrel 1
License:	Proprietary
Group:  	System/Kernel and hardware
URL:    	http://www.kernel.org/
# kernel-firmware tarball is generated from the git tree mentioned
# above, by simply cloning it and doing:
# tar --exclude-vcs -Jcf kernel-firmware-extra-version.tar.xz linux-firmware
Source: 	kernel-firmware-extra-%{version}.tar.xz
BuildRequires:	kernel-firmware >= 20110314-1
Conflicts:	kernel-firmware < 20110314-1
BuildRoot:	%{_tmppath}/%{name}-%{version}
BuildArch:	noarch

%description
This package contains extra redistributable etc. firmwares for in-kernel
drivers. It is shared for all kernels.

%prep
%setup -q -n linux-firmware

# don't include firmware already in kernel-firmware package
for fir in `rpm -ql kernel-firmware | grep '^/lib/firmware/' | \
            sed 's|^/lib/firmware/||'`; do
	[ -f "$fir" ] || continue
	rm -f "$fir"
done
for dir in `find . -type d | sed -e 's|^\.||' -e 's|^/||'`; do
	rmdir -p --ignore-fail-on-non-empty $dir
done

# remove files provided in iwlwifi-*-ucode* packages
rm -f LICENCE.iwlwifi_firmware
rm -f iwlwifi-{100-5,1000-3,{3945,4965,5150}-2,5000-{1,2,5},6000-4,6000g2{a,b}-5,6050-{4,5}}.ucode

# remove all radeon files as they are provided by kernel-firmware and radeon-firmware
rm -f LICENCE.radeon_rlc
rm -rf radeon

# remove files provided in rt*-firmware packages
rm -f LICENSE.ralink-firmware.txt
rm -f rt2561{,s}.bin rt2661.bin rt28{6,7}0.bin rt3090.bin rt73.bin

# remove unwanted source files
rm -f dsp56k/bootstrap.asm keyspan_pda/*.S
# FIXME: usbdux*.bin firmware should be in kernel-firmware or another
# separate package (not in non-free), usbdux*.bin is GPL licensed
rm -rf usbdux

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}/lib/firmware
cp -avf * %{buildroot}/lib/firmware
rm -f %{buildroot}/lib/firmware/LICENCE.*

%clean
rm -rf %{buildroot}

%files
%defattr(0644,root,root,0755)
%doc LICENCE.*
/lib/firmware/*


%changelog
* Sun May 22 2011 tmb <tmb> 20110517-1.mga1
+ Revision: 100133
- update to 2011-05-17 (adds some missing r8169 and bnx2 fw)

* Sat Apr 30 2011 tmb <tmb> 20110428-1.mga1
+ Revision: 93703
- update to 2011-04-28

* Mon Apr 11 2011 tmb <tmb> 20110310-4.mga1
+ Revision: 83067
- fix brcm80211 firmware names (#327)

* Mon Mar 21 2011 tmb <tmb> 20110310-3.mga1
+ Revision: 75330
- drop all radeon firmwares as they are now in radeon-firmware

* Thu Mar 17 2011 tmb <tmb> 20110310-2.mga1
+ Revision: 73538
- fix requires and conflicts on kernel-firmware

* Thu Mar 17 2011 tmb <tmb> 20110310-1.mga1
+ Revision: 73371
- update to 2011-03-10
- drop radeon and iwlwifi firmwares provided by separate rpms

* Tue Jan 25 2011 tmb <tmb> 20110125-1.mga1
+ Revision: 39060
- update to 2011-01-25 snapshot

* Sat Jan 08 2011 tmb <tmb> 20101220-2.mga1
+ Revision: 1233
- imported package kernel-firmware-extra


* Sat Jan  8 2011 Thomas Backlund <tmb@mageia.org> 20101220-2.mga1
- initial Mageia import
- drop rpm tags
- switch from manbo_mkrel to mkrel

* Thu Dec 30 2010 Thomas Backlund <tmb@mandriva.org> 20101220-1mnb2
+ Revision: 626441
- update to 2010-12-20 snapshot

* Thu Nov 04 2010 Thomas Backlund <tmb@mandriva.org> 20101102-1mnb2
+ Revision: 593286
- update to 2010-11-02

* Mon Sep 13 2010 Thomas Backlund <tmb@mandriva.org> 20100911-1mnb2
+ Revision: 577897
- update to 2010-09-11

* Sun Aug 15 2010 Thomas Backlund <tmb@mandriva.org> 20100807-1mnb2
+ Revision: 570141
- update to 2010-08-07

* Sun May 09 2010 Thomas Backlund <tmb@mandriva.org> 20100429-2mnb2
+ Revision: 544219
- remove rt3090 firmware as it's already shipped in a separate rt3090-firmware rpm

* Sat May 01 2010 Thomas Backlund <tmb@mandriva.org> 20100429-1mnb2
+ Revision: 541452
- update to 20100429
  - adds Amd Evergreen (HD5xxx) firmwares
  - adds Atheros ar9271 firmware
  - adds Ralink rt3070, rt3071, rt3090 firmwares
  - adds Sensoray s2250 firmware
  - adds Realtek 8192e firmware
  - adds Atheros Bluetooth ar3011 firmware

* Sun Feb 07 2010 Thomas Backlund <tmb@mandriva.org> 20100108-1mnb2
+ Revision: 501691
- remove iwlwifi firmwares provided by separate rpms
- update BR and Conflicts on kernel-firmware
- update to 2010-01-08

* Tue Nov 17 2009 Claudio Matsuoka <claudio@mandriva.com> 20091117-1mnb2
+ Revision: 467038
- Add firmware for p54 and kernel > 2.6.28

* Fri Jul 24 2009 Thomas Backlund <tmb@mandriva.org> 20090723-1mnb2
+ Revision: 399154
- update to 2009-07-23

* Fri May 29 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090514-2mnb2
+ Revision: 380763
- Prevent some more source files to ship with main package.

* Fri May 29 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090514-1mnb2
+ Revision: 380700
- Updated to 20090514
- Use lzma for source tarball.

* Mon Mar 30 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090212-2mnb2
+ Revision: 362324
- Firmwares not splitted anymore by license from kernel-firmware package
  (#49195):
  * removed previous conflicts not needed anymore, and now uneeded
    obsoletes.
  * rebuild against kernel-firmware >= 20090111-2mnb2

* Wed Mar 18 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090212-1mnb2
+ Revision: 357429
- Updated to 20090212

* Tue Feb 17 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20090120-1mnb2
+ Revision: 341924
- Updated to 20090120

* Fri Dec 05 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20081112-2mnb2
+ Revision: 310798
- Rebuild against kernel-firmware-20080922-2mnb2 (to provide all
  non-free firmware here).

* Fri Dec 05 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 20081112-1mnb2
+ Revision: 310727
- import kernel-firmware-extra


